==> google_cloud_bigtable-2.0.0.dev1-py2.py3-none-any.whl: google/cloud/bigtable_v2/services/bigtable/transports/base.py <==
# -*- coding: utf-8 -*-

# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

import abc
import typing
import pkg_resources

from google import auth  # type: ignore
from google.api_core import exceptions  # type: ignore
from google.api_core import gapic_v1  # type: ignore
from google.api_core import retry as retries  # type: ignore
from google.auth import credentials  # type: ignore

from google.cloud.bigtable_v2.types import bigtable


try:
    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
        gapic_version=pkg_resources.get_distribution("google-cloud-bigtable",).version,
    )
except pkg_resources.DistributionNotFound:
    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()


class BigtableTransport(abc.ABC):
    """Abstract transport class for Bigtable."""

    AUTH_SCOPES = (
        "https://www.googleapis.com/auth/bigtable.data",
        "https://www.googleapis.com/auth/bigtable.data.readonly",
        "https://www.googleapis.com/auth/cloud-bigtable.data",
        "https://www.googleapis.com/auth/cloud-bigtable.data.readonly",
        "https://www.googleapis.com/auth/cloud-platform",
        "https://www.googleapis.com/auth/cloud-platform.read-only",
    )

    def __init__(
        self,
        *,
        host: str = "bigtable.googleapis.com",
        credentials: credentials.Credentials = None,
        credentials_file: typing.Optional[str] = None,
        scopes: typing.Optional[typing.Sequence[str]] = AUTH_SCOPES,
        quota_project_id: typing.Optional[str] = None,
        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
        **kwargs,
    ) -> None:
        """Instantiate the transport.

        Args:
            host (Optional[str]): The hostname to connect to.
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            credentials_file (Optional[str]): A file with credentials that can
                be loaded with :func:`google.auth.load_credentials_from_file`.
                This argument is mutually exclusive with credentials.
            scope (Optional[Sequence[str]]): A list of scopes.
            quota_project_id (Optional[str]): An optional project to use for billing
                and quota.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):	
                The client info used to send a user-agent string along with	
                API requests. If ``None``, then default info will be used.	
                Generally, you only need to set this if you're developing	
                your own client library.
        """
        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
        if ":" not in host:
            host += ":443"
        self._host = host

        # If no credentials are provided, then determine the appropriate
        # defaults.
        if credentials and credentials_file:
            raise exceptions.DuplicateCredentialArgs(
                "'credentials_file' and 'credentials' are mutually exclusive"
            )

        if credentials_file is not None:
            credentials, _ = auth.load_credentials_from_file(
                credentials_file, scopes=scopes, quota_project_id=quota_project_id
            )

        elif credentials is None:
            credentials, _ = auth.default(
                scopes=scopes, quota_project_id=quota_project_id
            )

        # Save the credentials.
        self._credentials = credentials

        # Lifted into its own function so it can be stubbed out during tests.
        self._prep_wrapped_messages(client_info)

    def _prep_wrapped_messages(self, client_info):
        # Precompute the wrapped methods.
        self._wrapped_methods = {
            self.read_rows: gapic_v1.method.wrap_method(
                self.read_rows,
                default_retry=retries.Retry(
                    initial=0.01,
                    maximum=60.0,
                    multiplier=2,
                    predicate=retries.if_exception_type(),
                ),
                default_timeout=43200.0,
                client_info=client_info,
            ),
            self.sample_row_keys: gapic_v1.method.wrap_method(
                self.sample_row_keys,
                default_retry=retries.Retry(
                    initial=0.01,
                    maximum=60.0,
                    multiplier=2,
                    predicate=retries.if_exception_type(),
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.mutate_row: gapic_v1.method.wrap_method(
                self.mutate_row,
                default_retry=retries.Retry(
                    initial=0.01,
                    maximum=60.0,
                    multiplier=2,
                    predicate=retries.if_exception_type(
                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                    ),
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.mutate_rows: gapic_v1.method.wrap_method(
                self.mutate_rows,
                default_retry=retries.Retry(
                    initial=0.01,
                    maximum=60.0,
                    multiplier=2,
                    predicate=retries.if_exception_type(),
                ),
                default_timeout=600.0,
                client_info=client_info,
            ),
            self.check_and_mutate_row: gapic_v1.method.wrap_method(
                self.check_and_mutate_row,
                default_retry=retries.Retry(
                    initial=0.01,
                    maximum=60.0,
                    multiplier=2,
                    predicate=retries.if_exception_type(),
                ),
                default_timeout=20.0,
                client_info=client_info,
            ),
            self.read_modify_write_row: gapic_v1.method.wrap_method(
                self.read_modify_write_row,
                default_retry=retries.Retry(
                    initial=0.01,
                    maximum=60.0,
                    multiplier=2,
                    predicate=retries.if_exception_type(),
                ),
                default_timeout=20.0,
                client_info=client_info,
            ),
        }

    @property
    def read_rows(
        self,
    ) -> typing.Callable[
        [bigtable.ReadRowsRequest],
        typing.Union[
            bigtable.ReadRowsResponse, typing.Awaitable[bigtable.ReadRowsResponse]
        ],
    ]:
        raise NotImplementedError()

    @property
    def sample_row_keys(
        self,
    ) -> typing.Callable[
        [bigtable.SampleRowKeysRequest],
        typing.Union[
            bigtable.SampleRowKeysResponse,
            typing.Awaitable[bigtable.SampleRowKeysResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def mutate_row(
        self,
    ) -> typing.Callable[
        [bigtable.MutateRowRequest],
        typing.Union[
            bigtable.MutateRowResponse, typing.Awaitable[bigtable.MutateRowResponse]
        ],
    ]:
        raise NotImplementedError()

    @property
    def mutate_rows(
        self,
    ) -> typing.Callable[
        [bigtable.MutateRowsRequest],
        typing.Union[
            bigtable.MutateRowsResponse, typing.Awaitable[bigtable.MutateRowsResponse]
        ],
    ]:
        raise NotImplementedError()

    @property
    def check_and_mutate_row(
        self,
    ) -> typing.Callable[
        [bigtable.CheckAndMutateRowRequest],
        typing.Union[
            bigtable.CheckAndMutateRowResponse,
            typing.Awaitable[bigtable.CheckAndMutateRowResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def read_modify_write_row(
        self,
    ) -> typing.Callable[
        [bigtable.ReadModifyWriteRowRequest],
        typing.Union[
            bigtable.ReadModifyWriteRowResponse,
            typing.Awaitable[bigtable.ReadModifyWriteRowResponse],
        ],
    ]:
        raise NotImplementedError()


__all__ = ("BigtableTransport",)

==> google_cloud_bigtable-2.1.0-py2.py3-none-any.whl: google/cloud/bigtable_v2/services/bigtable/transports/base.py <==
# -*- coding: utf-8 -*-

# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

import abc
import typing
import pkg_resources

from google import auth  # type: ignore
from google.api_core import exceptions  # type: ignore
from google.api_core import gapic_v1  # type: ignore
from google.api_core import retry as retries  # type: ignore
from google.auth import credentials  # type: ignore

from google.cloud.bigtable_v2.types import bigtable


try:
    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
        gapic_version=pkg_resources.get_distribution("google-cloud-bigtable",).version,
    )
except pkg_resources.DistributionNotFound:
    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()


class BigtableTransport(abc.ABC):
    """Abstract transport class for Bigtable."""

    AUTH_SCOPES = (
        "https://www.googleapis.com/auth/bigtable.data",
        "https://www.googleapis.com/auth/bigtable.data.readonly",
        "https://www.googleapis.com/auth/cloud-bigtable.data",
        "https://www.googleapis.com/auth/cloud-bigtable.data.readonly",
        "https://www.googleapis.com/auth/cloud-platform",
        "https://www.googleapis.com/auth/cloud-platform.read-only",
    )

    def __init__(
        self,
        *,
        host: str = "bigtable.googleapis.com",
        credentials: credentials.Credentials = None,
        credentials_file: typing.Optional[str] = None,
        scopes: typing.Optional[typing.Sequence[str]] = AUTH_SCOPES,
        quota_project_id: typing.Optional[str] = None,
        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
        **kwargs,
    ) -> None:
        """Instantiate the transport.

        Args:
            host (Optional[str]): The hostname to connect to.
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            credentials_file (Optional[str]): A file with credentials that can
                be loaded with :func:`google.auth.load_credentials_from_file`.
                This argument is mutually exclusive with credentials.
            scope (Optional[Sequence[str]]): A list of scopes.
            quota_project_id (Optional[str]): An optional project to use for billing
                and quota.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.
        """
        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
        if ":" not in host:
            host += ":443"
        self._host = host

        # Save the scopes.
        self._scopes = scopes or self.AUTH_SCOPES

        # If no credentials are provided, then determine the appropriate
        # defaults.
        if credentials and credentials_file:
            raise exceptions.DuplicateCredentialArgs(
                "'credentials_file' and 'credentials' are mutually exclusive"
            )

        if credentials_file is not None:
            credentials, _ = auth.load_credentials_from_file(
                credentials_file, scopes=self._scopes, quota_project_id=quota_project_id
            )

        elif credentials is None:
            credentials, _ = auth.default(
                scopes=self._scopes, quota_project_id=quota_project_id
            )

        # Save the credentials.
        self._credentials = credentials

    def _prep_wrapped_messages(self, client_info):
        # Precompute the wrapped methods.
        self._wrapped_methods = {
            self.read_rows: gapic_v1.method.wrap_method(
                self.read_rows,
                default_retry=retries.Retry(
                    initial=0.01,
                    maximum=60.0,
                    multiplier=2,
                    predicate=retries.if_exception_type(),
                    deadline=43200.0,
                ),
                default_timeout=43200.0,
                client_info=client_info,
            ),
            self.sample_row_keys: gapic_v1.method.wrap_method(
                self.sample_row_keys,
                default_retry=retries.Retry(
                    initial=0.01,
                    maximum=60.0,
                    multiplier=2,
                    predicate=retries.if_exception_type(),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.mutate_row: gapic_v1.method.wrap_method(
                self.mutate_row,
                default_retry=retries.Retry(
                    initial=0.01,
                    maximum=60.0,
                    multiplier=2,
                    predicate=retries.if_exception_type(
                        exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.mutate_rows: gapic_v1.method.wrap_method(
                self.mutate_rows,
                default_retry=retries.Retry(
                    initial=0.01,
                    maximum=60.0,
                    multiplier=2,
                    predicate=retries.if_exception_type(),
                    deadline=600.0,
                ),
                default_timeout=600.0,
                client_info=client_info,
            ),
            self.check_and_mutate_row: gapic_v1.method.wrap_method(
                self.check_and_mutate_row,
                default_retry=retries.Retry(
                    initial=0.01,
                    maximum=60.0,
                    multiplier=2,
                    predicate=retries.if_exception_type(),
                    deadline=20.0,
                ),
                default_timeout=20.0,
                client_info=client_info,
            ),
            self.read_modify_write_row: gapic_v1.method.wrap_method(
                self.read_modify_write_row,
                default_retry=retries.Retry(
                    initial=0.01,
                    maximum=60.0,
                    multiplier=2,
                    predicate=retries.if_exception_type(),
                    deadline=20.0,
                ),
                default_timeout=20.0,
                client_info=client_info,
            ),
        }

    @property
    def read_rows(
        self,
    ) -> typing.Callable[
        [bigtable.ReadRowsRequest],
        typing.Union[
            bigtable.ReadRowsResponse, typing.Awaitable[bigtable.ReadRowsResponse]
        ],
    ]:
        raise NotImplementedError()

    @property
    def sample_row_keys(
        self,
    ) -> typing.Callable[
        [bigtable.SampleRowKeysRequest],
        typing.Union[
            bigtable.SampleRowKeysResponse,
            typing.Awaitable[bigtable.SampleRowKeysResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def mutate_row(
        self,
    ) -> typing.Callable[
        [bigtable.MutateRowRequest],
        typing.Union[
            bigtable.MutateRowResponse, typing.Awaitable[bigtable.MutateRowResponse]
        ],
    ]:
        raise NotImplementedError()

    @property
    def mutate_rows(
        self,
    ) -> typing.Callable[
        [bigtable.MutateRowsRequest],
        typing.Union[
            bigtable.MutateRowsResponse, typing.Awaitable[bigtable.MutateRowsResponse]
        ],
    ]:
        raise NotImplementedError()

    @property
    def check_and_mutate_row(
        self,
    ) -> typing.Callable[
        [bigtable.CheckAndMutateRowRequest],
        typing.Union[
            bigtable.CheckAndMutateRowResponse,
            typing.Awaitable[bigtable.CheckAndMutateRowResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def read_modify_write_row(
        self,
    ) -> typing.Callable[
        [bigtable.ReadModifyWriteRowRequest],
        typing.Union[
            bigtable.ReadModifyWriteRowResponse,
            typing.Awaitable[bigtable.ReadModifyWriteRowResponse],
        ],
    ]:
        raise NotImplementedError()


__all__ = ("BigtableTransport",)
